package VMOMI::HostDiskPartitionInfoType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
